# Test Coverage Report

Generated: Thu 2013-02-28 14:37 SGT

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 99 | 72 | 20 | 91.1%
subscribe.__init__ | 1 | 1 | 0 | 100.0%
subscribe.forms | 27 | 24 | 3 | 100.0%
subscribe.models | 14 | 8 | 6 | 100.0%
subscribe.templatetags.subscriptions_tags | 18 | 14 | 3 | 93.3%
subscribe.tests.test_app.models | 3 | 2 | 1 | 100.0%
subscribe.views | 36 | 23 | 7 | 79.3%

Excluded packages and modules
Error packages and modules